@@ -22,12 +22,17 @@ class EnumDefinition:
     elements: List[EnumElement]
 
     def __init__(self, definition: List[str]):
+        definition = [line for line in definition if
+                      not line.startswith("    def") and
+                      not line.startswith("        ")
+                      ]
+
         self.name = definition[0].removeprefix("class ").removesuffix("(Enum):")
         self.elements = [EnumElement(line) for line in definition[1:]]
 
     def get_typescript(self) -> str:
         """Return the enum in typescript syntax (including indentation)."""
-        typescript_string = "enum {0} {{\n".format(self.name)
+        typescript_string = "export enum {0} {{\n".format(self.name)
         for element in self.elements:
             typescript_string += "{}\n".format(element.get_typescript())
         typescript_string += "}"
